@@ -3,6 +3,7 @@ from __future__ import annotations
 import asyncio
 import contextlib
 import re
+import time
 from pathlib import Path
 from typing import Any
 
@@ -11,6 +12,7 @@ from redbot.core.i18n import Translator
 from redbot.core.utils.chat_formatting import inline
 
 from pylav import emojis
+from pylav.constants import BUNDLED_NODES_IDS
 from pylav.sql.models import NodeModel
 from pylav.types import BotT, CogT, ContextT, InteractionT
 from pylav.utils import PyLavContext
@@ -148,7 +150,7 @@ class AddNodeFlow(discord.ui.View):
         self.reconnect_attempts = -1
         self.ssl = False
         self.search_only = False
-        self.unique_identifier = None
+        self.unique_identifier = int(time.time())
         self.done = False
 
         self.add_item(self.done_button)
@@ -460,6 +462,7 @@ class NodeManagerMenu(BaseMenu):
             starting_page=starting_page,
             **kwargs,
         )
+        self.unique_identifier = int(time.time())
         self.current_page = -1
         self.forward_button = NavigateButton(
             style=discord.ButtonStyle.grey,
@@ -596,7 +599,7 @@ class NodeManagerMenu(BaseMenu):
             self.last_button.disabled = True
         if self.source.target:
             self.add_item(self.show_sources_button)
-            if not self.source.target.managed:
+            if self.source.target.identifier not in BUNDLED_NODES_IDS:
                 self.add_item(self.done_button)
                 self.add_item(self.search_only_button)
                 self.add_item(self.ssl_button)
